@@ -51,8 +51,14 @@ from starlite_saqlalchemy import (
     settings,
     sqlalchemy_plugin,
 )
-from starlite_saqlalchemy.health import health_check
+from starlite_saqlalchemy.exceptions import HealthCheckConfigurationError
+from starlite_saqlalchemy.health import (
+    AbstractHealthCheck,
+    AppHealthCheck,
+    HealthController,
+)
 from starlite_saqlalchemy.service import make_service_callback
+from starlite_saqlalchemy.sqlalchemy_plugin import SQLAlchemyHealthCheck
 from starlite_saqlalchemy.type_encoders import type_encoders_map
 from starlite_saqlalchemy.worker import create_worker_instance
 
@@ -60,6 +66,7 @@ if TYPE_CHECKING:
     from starlite.config.app import AppConfig
     from starlite.types import TypeEncodersMap
 
+
 T = TypeVar("T")
 
 
@@ -160,6 +167,7 @@ class PluginConfig(BaseModel):
     """Chain of structlog log processors."""
     type_encoders: TypeEncodersMap = type_encoders_map
     """Map of type to serializer callable."""
+    health_checks: Sequence[type[AbstractHealthCheck]] = [AppHealthCheck, SQLAlchemyHealthCheck]
 
 
 class ConfigureApp:
@@ -283,7 +291,14 @@ class ConfigureApp:
             app_config: The Starlite application config object.
         """
         if self.config.do_health_check:
-            app_config.route_handlers.append(health_check)
+            healt_checks: list[AbstractHealthCheck] = []
+            for health_check in self.config.health_checks:
+                health_check_instance = health_check()
+                if not health_check_instance.name:
+                    raise HealthCheckConfigurationError(f"{health_check}.name must be set.")
+                healt_checks.append(health_check_instance)
+            HealthController.health_checks = healt_checks
+            app_config.route_handlers.append(HealthController)
 
     def configure_logging(self, app_config: AppConfig) -> None:
         """Configure application logging.
